@@ -18,14 +18,14 @@ sub no_presentation {
 
 ################################################################################
 
-sub draw_page {
+sub draw_hash {
 
-	my ($_SKIN, $page) = @_;
+	my ($_SKIN, $h) = @_;
 
 	$_REQUEST {__content_type} ||= 'text/plain; charset=' . $i18n -> {_charset};
 						
 	return XML::Simple::XMLout (
-		{ content => $page -> {content} }, 
+		$h, 
 		RootName => 'data', 
 		XMLDecl  => qq{<?xml version="1.0" encoding="$i18n->{_charset}"?>},
 	)
@@ -34,19 +34,38 @@ sub draw_page {
 
 ################################################################################
 
+sub draw_page {
+
+	my ($_SKIN, $page) = @_;
+	
+	return $_SKIN -> draw_hash ({ 
+		content => $page -> {content}
+	});
+
+}
+
+################################################################################
+
 sub draw_error_page {
 
 	my ($_SKIN, $page) = @_;
 
-	$_REQUEST {__content_type} ||= 'text/plain; charset=' . $i18n -> {_charset};
-
-	return XML::Simple::XMLout ({
+	return $_SKIN -> draw_hash ({ 
 		message => $_REQUEST {error},
 		field   => $page -> {error_field},
-	}, 
-		RootName => 'error',
-		XMLDecl  => qq{<?xml version="1.0" encoding="$i18n->{_charset}"?>},
-	);
+	});
+
+}
+
+################################################################################
+
+sub draw_redirect_page {
+
+	my ($_SKIN, $page) = @_;
+
+	return $_SKIN -> draw_hash ({ 
+		url   => $page -> {url},
+	});
 
 }
 
